#! /usr/bin/env node
var _semver = require('semver');

var _semver2 = _interopRequireDefault(_semver);

var _npmRun = require('npm-run');

var _npmRun2 = _interopRequireDefault(_npmRun);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

/* eslint no-console: 0 */

var reactEnv = process.env.REACT;
var reactArg = process.argv[2];

if (reactEnv && !_semver2['default'].validRange(reactEnv)) {
  throw new Error('REACT environment variable is not a valid semver range');
}

if (reactArg && !_semver2['default'].validRange(reactArg)) {
  throw new Error('Argument supplied to enzyme-adapter-react-install is not a valid semver range');
}

var reactVersion = reactEnv || reactArg;

if (!_semver2['default'].intersects(reactVersion, '>=0.13')) {
  throw new Error('semver range is not valid. Please provide a valid semver range as an argument or environment variable.');
}

console.log('Cleaning up React and related packages...');
var commands = ['npm uninstall --no-save react-dom react-test-renderer react-addons-test-utils enzyme-adapter-react-14 enzyme-adapter-react-15.4 enzyme-adapter-react-15 enzyme-adapter-react-16', 'rimraf node_modules/react-test-renderer node_modules/react', 'npm prune'];

try {
  commands.forEach(function (cmd) {
    _npmRun2['default'].execSync(cmd, { stdio: 'inherit' });
  });
} catch (e) {
  console.error('An uninstallation failed');
  console.log(e);
  process.exit(1);
}

console.log('Installing React@' + String(reactVersion) + ' and related packages...');
if (_semver2['default'].intersects(reactVersion, '^16.0.0-0')) {
  try {
    _npmRun2['default'].execSync('install-peerdeps -S enzyme-adapter-react-16', { stdio: 'inherit' });
  } catch (e) {
    console.error('An installation failed');
    console.log(e);
    process.exit(16);
  }
} else if (_semver2['default'].intersects(reactVersion, '^15.5.0')) {
  try {
    _npmRun2['default'].execSync('install-peerdeps -S enzyme-adapter-react-15', { stdio: 'inherit' });
  } catch (e) {
    console.error('An installation failed');
    console.log(e);
    process.exit(155);
  }
} else if (_semver2['default'].intersects(reactVersion, '15.0.0-0 - 15.4.x')) {
  try {
    _npmRun2['default'].execSync('install-peerdeps -S enzyme-adapter-react-15.4', { stdio: 'inherit' });
  } catch (e) {
    console.error('An installation failed');
    console.log(e);
    process.exit(15);
  }
} else if (_semver2['default'].intersects(reactVersion, '^0.14.0')) {
  try {
    _npmRun2['default'].execSync('install-peerdeps -S enzyme-adapter-react-14', { stdio: 'inherit' });
  } catch (e) {
    console.error('An installation failed');
    console.log(e);
    process.exit(14);
  }
} else if (_semver2['default'].intersects(reactVersion, '^0.13.0')) {
  try {
    _npmRun2['default'].execSync('install-peerdeps -S enzyme-adapter-react-13', { stdio: 'inherit' });
  } catch (e) {
    console.error('An installation failed');
    console.log(e);
    process.exit(13);
  }
}